#' Baffle: Waffle graphs with base graphics
#'
#' The package provides functions to make waffle graphs in the base graphics.
#'
#' Waffle plots are rectangular pie charts that represent a quantity or abundances using
#' colored squares or other symbol. This makes them better at transmitting information as the
#' discrete number of squares is easier to read than the circular area of pie charts.
#' While the original waffle charts were rectangular with 10 rows and columns, with a single square
#' representing 1%, they are nowadays popular in various infographics to visualize any
#' proportional ratios.
#' 
#' @docType package
#' @keywords internal
"_PACKAGE"
